@@ -212,7 +212,23 @@ class HttpOrigin(
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpOrigin.__init__)
+            def stub(
+                domain_name: builtins.str,
+                *,
+                http_port: typing.Optional[jsii.Number] = None,
+                https_port: typing.Optional[jsii.Number] = None,
+                keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                origin_ssl_protocols: typing.Optional[typing.Sequence[aws_cdk.aws_cloudfront.OriginSslPolicy]] = None,
+                protocol_policy: typing.Optional[aws_cdk.aws_cloudfront.OriginProtocolPolicy] = None,
+                read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
         props = HttpOriginProps(
             http_port=http_port,
@@ -311,7 +327,22 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HttpOriginProps.__init__)
+            def stub(
+                *,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+                http_port: typing.Optional[jsii.Number] = None,
+                https_port: typing.Optional[jsii.Number] = None,
+                keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                origin_ssl_protocols: typing.Optional[typing.Sequence[aws_cdk.aws_cloudfront.OriginSslPolicy]] = None,
+                protocol_policy: typing.Optional[aws_cdk.aws_cloudfront.OriginProtocolPolicy] = None,
+                read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
             check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
             check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
@@ -540,7 +571,23 @@ class LoadBalancerV2Origin(
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadBalancerV2Origin.__init__)
+            def stub(
+                load_balancer: aws_cdk.aws_elasticloadbalancingv2.ILoadBalancerV2,
+                *,
+                http_port: typing.Optional[jsii.Number] = None,
+                https_port: typing.Optional[jsii.Number] = None,
+                keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                origin_ssl_protocols: typing.Optional[typing.Sequence[aws_cdk.aws_cloudfront.OriginSslPolicy]] = None,
+                protocol_policy: typing.Optional[aws_cdk.aws_cloudfront.OriginProtocolPolicy] = None,
+                read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         props = LoadBalancerV2OriginProps(
             http_port=http_port,
@@ -623,7 +670,22 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoadBalancerV2OriginProps.__init__)
+            def stub(
+                *,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+                http_port: typing.Optional[jsii.Number] = None,
+                https_port: typing.Optional[jsii.Number] = None,
+                keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                origin_ssl_protocols: typing.Optional[typing.Sequence[aws_cdk.aws_cloudfront.OriginSslPolicy]] = None,
+                protocol_policy: typing.Optional[aws_cdk.aws_cloudfront.OriginProtocolPolicy] = None,
+                read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
             check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
             check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
@@ -854,7 +916,9 @@ class OriginGroup(
         :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(OriginGroup.bind)
+            def stub(scope: aws_cdk.core.Construct, *, origin_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
 
@@ -901,7 +965,14 @@ class OriginGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(OriginGroupProps.__init__)
+            def stub(
+                *,
+                fallback_origin: aws_cdk.aws_cloudfront.IOrigin,
+                primary_origin: aws_cdk.aws_cloudfront.IOrigin,
+                fallback_status_codes: typing.Optional[typing.Sequence[jsii.Number]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument fallback_origin", value=fallback_origin, expected_type=type_hints["fallback_origin"])
             check_type(argname="argument primary_origin", value=primary_origin, expected_type=type_hints["primary_origin"])
             check_type(argname="argument fallback_status_codes", value=fallback_status_codes, expected_type=type_hints["fallback_status_codes"])
@@ -986,7 +1057,18 @@ class RestApiOrigin(
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RestApiOrigin.__init__)
+            def stub(
+                rest_api: aws_cdk.aws_apigateway.RestApi,
+                *,
+                keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rest_api", value=rest_api, expected_type=type_hints["rest_api"])
         props = RestApiOriginProps(
             keepalive_timeout=keepalive_timeout,
@@ -1059,7 +1141,17 @@ class RestApiOriginProps(aws_cdk.aws_cloudfront.OriginOptions):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RestApiOriginProps.__init__)
+            def stub(
+                *,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+                keepalive_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                read_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
             check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
             check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
@@ -1218,7 +1310,18 @@ class S3Origin(
         :param origin_shield_region: When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. Default: - origin shield not enabled
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3Origin.__init__)
+            def stub(
+                bucket: aws_cdk.aws_s3.IBucket,
+                *,
+                origin_access_identity: typing.Optional[aws_cdk.aws_cloudfront.IOriginAccessIdentity] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
         props = S3OriginProps(
             origin_access_identity=origin_access_identity,
@@ -1244,7 +1347,9 @@ class S3Origin(
         :param origin_id: The identifier of this Origin, as assigned by the Distribution this Origin has been used added to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3Origin.bind)
+            def stub(scope: aws_cdk.core.Construct, *, origin_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
 
@@ -1297,7 +1402,17 @@ class S3OriginProps(aws_cdk.aws_cloudfront.OriginProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3OriginProps.__init__)
+            def stub(
+                *,
+                connection_attempts: typing.Optional[jsii.Number] = None,
+                connection_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+                custom_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                origin_shield_region: typing.Optional[builtins.str] = None,
+                origin_path: typing.Optional[builtins.str] = None,
+                origin_access_identity: typing.Optional[aws_cdk.aws_cloudfront.IOriginAccessIdentity] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument connection_attempts", value=connection_attempts, expected_type=type_hints["connection_attempts"])
             check_type(argname="argument connection_timeout", value=connection_timeout, expected_type=type_hints["connection_timeout"])
             check_type(argname="argument custom_headers", value=custom_headers, expected_type=type_hints["custom_headers"])
